summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmrainbowedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmrainbowedit.h')
-rw-r--r--kpovmodeler/pmrainbowedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmrainbowedit.h b/kpovmodeler/pmrainbowedit.h
index d520f6e2..e2c4698d 100644
--- a/kpovmodeler/pmrainbowedit.h
+++ b/kpovmodeler/pmrainbowedit.h
@@ -38,12 +38,13 @@ class TQLabel;
class PMRainbowEdit : public PMTextureBaseEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMRainbowEdit with parent and name
*/
- PMRainbowEdit( TQWidget* parent, const char* name = 0 );
+ PMRainbowEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -38,12 +38,13 @@ class TQLabel;
public:
/**
- * Creates a PMRainbowEdit with parent and name
+ * Creates a PMRainbowEdit with tqparent and name
*/